# `relationalai.std.graphs.Graph.id`

The unique integer ID assigned to the graph instance.

## Example

```python
import relationalai as rai
from relationalai.std.graphs import Graph

model = rai.Model("myModel")
graph = Graph(model)

print(graph.id)
# Output:
# 1
```
